searchData={"items":[{"type":"module","title":"Enux","doc":"utility package for loading, validating and documenting your app's configuration variables from env, json, jsonc and toml files at runtime and injecting them into your environment","ref":"Enux.html"},{"type":"module","title":"Installation - Enux","doc":"```\ndefp deps do\n  [\n    {:enux, \"~> 1.5\"},\n\n    # if you want to load `.jsonc` files, you should have this\n    # you can also use this for `.json` files\n    {:jsonc, \"~> 0.9\"},\n\n    # if you want to load `.json` files, you should have either this\n    \n    {:euneus, \"~> 1.1\"}\n    # or this\n    {:jason, \"~> 1.4\"}\n    # or this\n    {:jaxon, \"~> 2.0\"}\n    # or this\n    {:jiffy, \"~> 1.1\"}\n    # or this\n    {:json, \"~> 1.4\"}\n    # or this\n    {:jsone, \"~> 1.8\"}\n    # or this\n    {:jsonrs, \"~> 0.3\"}\n    # or this\n    {:poison, \"~> 5.0\"}\n    # or this\n    {:thoas, \"~> 1.2\"}\n\n    # if you want to load `.toml` files, you should have either this\n    {:tomerl, \"~> 0.5\"}\n    # or this\n    {:toml, \"~> 0.7\"}\n  ]\nend\n```","ref":"Enux.html#module-installation"},{"type":"module","title":"Usage - Enux","doc":"In elixir 1.11, `config/runtime.exs` was introduced. This is a file that is executed exactly before your application starts.\nThis is a proper place to load any configuration variables into your app. If this file does not exist in your project directory,\ncreate it and add these lines to it:\n```\nimport Config\nenv = Enux.load()\nconfig :otp_app, env\n```\nWhen you start your application, you can access your configuration variables using `Applicatoin.get_env`.\nIf you need to url encode your configuration values, just pass `url_encoded: true` to `Enux.load`.\n\nYou should have either [poison](https://hex.pm/packages/poison) or [jason](https://hex.pm/packages/jason) or [jaxon](https://hex.pm/packages/jaxon)\nor [thoas](https://hex.pm/packages/thoas) or [jsone](https://hex.pm/packages/jsone) or [jiffy](https://hex.pm/packages/jiffy) or [json](https://hex.pm/packages/json) or\n[jsonrs](https://hex.pm/packages/jsonrs) or [euneus](https://hex.pm/packages/euneus) in your dependencies if you want to use `.json` files.\n\nTo use `.jsonc` files, you should have [jsonc](https://hex.pm/packages/jsonc). You can also use this package for `.json` files.\nTo use `.toml` files, you should have either [toml](https://hex.pm/packages/toml) or [tomerl](https://hex.pm/packages/tomerl) or [tomlex](https://hex.pm/packages/tomlex).\n\nYou can load multiple files of different kinds:\n```\nimport Config\n\nenv1 = Enux.load(\"config/one.env\", url_encoded: true)\nconfig :otp_app, env1\n\nenv2 = Enux.load(\"config/two.json\")\nconfig :otp_app, :two, env2\n```\n\n#","ref":"Enux.html#module-usage"},{"type":"module","title":"automatic loading - Enux","doc":"Another way of using Enux is using the `Enux.autoload` function which will load all `.env`, `.json`, `.jsonc` and `.toml` files in your `config` directory.\nit makes more sense to call this function in your `config/runtime.exs` but you can call it anywhere in your code.\n\nIf you have `config/pg.env` and `config/redis.json` in your project directory, after calling `Enux.autoload(:otp_app)`, you can access the variables\nusing `Application.get_env(:otp_app, :pg)` and `Application.get_env(:otp_app, :redis)`. if a file is named `.env` or `.json` or `.jsonc` or `.toml`, you should use\n`Application.get_env(:otp_app, :env)` or `Application.get_env(:otp_app, :json)` or `Application.get_env(:otp_app, :jsonc)` or `Application.get_env(:otp_app, :toml)` respectively.\n```\nEnux.autoload(:otp_app)\n```\n\n#","ref":"Enux.html#module-automatic-loading"},{"type":"module","title":"multiple environments - Enux","doc":"Using the `MIX_ENV` environmental variable you can adjust which files `Enux.autoload` loads into your app. If `MIX_ENV` is not specified, `dev` will be assumed.\nThe only thing you need to do is specifying the environment in the name of each file like `db-staging.env`, `redis-prod.jsonc` or `rabbitmq-unit-tests.toml`.\nBut after the file is loaded, you can access the variables using e.g. `Application.get_env(:otp_app, :db) or Application.get_env(:otp_app, :redis)` or\n`Application.get_env(:otp_app, :rabbitmq)`.\nIf a file doesn't have `-` in its name, `Enux.autoload` will load it regardless of the value of `MIX_ENV`.\n\n#","ref":"Enux.html#module-multiple-environments"},{"type":"module","title":"environment validation - Enux","doc":"You may also use `Enux.expect` to both validate and document your required environment. first you need to define a schema:\n```\nschema = [\n  id: [&is_integer/1, fn id -> id > 1000 end],\n  username: [&is_binary/1, fn u -> String.length(u) > 8 end],\n  metadata: [],\n  profile: [\n    full_name: [&is_binary/1],\n    age: [&is_number/1]\n  ]\n]\n```\nthen the following line will check for compliance of your environment under `:otp_app` and `:key` with the schema defined above\n(an empty list implies only checking for existence):\n```\nEnux.expect(:otp_app, :key, schema)\n```","ref":"Enux.html#module-environment-validation"},{"type":"function","title":"Enux.autoload/2","doc":"automatically loads all `.env`, `.json`, `.jsonc` and `.toml` files in your `config` directory.\npass your project's name as an atom. you can also still pass `url_encoded: true` to it.","ref":"Enux.html#autoload/2"},{"type":"function","title":"Enux.expect/3","doc":"checks if the environment variables under `app` and `key` comply with the given `schema`. any non-compliance results in an error.\nyou can use this function for both validating and documenting your required environment.","ref":"Enux.html#expect/3"},{"type":"function","title":"Enux.load/0","doc":"reads the variables in `config/.env` and returns a formatted keyword list.\nall values are loaded as they are.","ref":"Enux.html#load/0"},{"type":"function","title":"Enux.load/1","doc":"reads the variables in `config/.env` and returns a formatted keyword list","ref":"Enux.html#load/1"},{"type":"function","title":"Enux.load/2","doc":"reads the variables in the given path(could be `.env`, `.json`, `.jsonc` or `.toml` file) and returns a formatted keyword list","ref":"Enux.html#load/2"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS","ref":"license.html"},{"type":"extras","title":"Enux","doc":"# Enux\n\nutility package for loading, validating and documenting your app's configuration variables from env, json, jsonc and toml files at runtime and injecting them into your environment","ref":"readme.html"},{"type":"extras","title":"Installation - Enux","doc":"The package can be installed by adding `enux` to your list of dependencies in `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    {:enux, \"~> 1.5\"},\n\n    # if you want to load `.jsonc` files, you should have this\n    # you can also use this for `.json` files\n    {:jsonc, \"~> 0.9\"},\n\n    # if you want to load `.json` files, you should have either this\n    {:euneus, \"~> 1.1\"}\n    # or this\n    {:jason, \"~> 1.4\"}\n    # or this\n    {:jaxon, \"~> 2.0\"}\n    # or this\n    {:jiffy, \"~> 1.1\"}\n    # or this\n    {:json, \"~> 1.4\"}\n    # or this\n    {:jsone, \"~> 1.8\"}\n    # or this\n    {:jsonrs, \"~> 0.3\"}\n    # or this\n    {:poison, \"~> 5.0\"}\n    # or this\n    {:thoas, \"~> 1.2\"}\n\n\n    # if you want to load `.toml` files, you should have either this\n    {:tomerl, \"~> 0.5\"}\n    # or this\n    {:toml, \"~> 0.7\"}\n  ]\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/enux](https://hexdocs.pm/enux).","ref":"readme.html#installation"}],"content_type":"text/markdown"}